@@ -29,10 +29,10 @@ import queue
 import random
 import traceback
 from http.server import BaseHTTPRequestHandler, HTTPServer
+from multiprocessing.context import ForkProcess
 from unittest import TestCase
 from unittest.mock import patch, MagicMock
 from threading import Thread, Event
-from multiprocessing import Process
 from decimal import Decimal
 import datetime as dt
 import urllib3.exceptions
@@ -116,6 +116,7 @@ class HttpClientTest(TestCase):
     def test_no_connection_exception(self):
         client = Client()
         self.assertRaises(ConnectionError, client.sql, 'select foo')
+        client.close()
 
     @patch(REQUEST)
     def test_http_error_is_re_raised(self, request):
@@ -123,6 +124,7 @@ class HttpClientTest(TestCase):
 
         client = Client()
         self.assertRaises(ProgrammingError, client.sql, 'select foo')
+        client.close()
 
     @patch(REQUEST)
     def test_programming_error_contains_http_error_response_content(self, request):
@@ -283,6 +285,7 @@ class HttpClientTest(TestCase):
         self.assertTrue(
             (socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1) in conn_kw['socket_options']
         )
+        client.close()
 
 
 @patch(REQUEST, fail_sometimes)
@@ -310,7 +313,7 @@ class ThreadSafeHttpClientTest(TestCase):
 
     def setUp(self):
         self.client = Client(self.servers)
-        self.client.retry_interval = 0.1  # faster retry
+        self.client.retry_interval = 0.2  # faster retry
 
     def tearDown(self):
         self.client.close()
@@ -396,7 +399,7 @@ class KeepAliveClientTest(TestCase):
 
     def __init__(self, *args, **kwargs):
         super(KeepAliveClientTest, self).__init__(*args, **kwargs)
-        self.server_process = Process(target=self._run_server)
+        self.server_process = ForkProcess(target=self._run_server)
 
     def setUp(self):
         super(KeepAliveClientTest, self).setUp()
@@ -529,8 +532,8 @@ class TestingHttpServerTestCase(TestCase):
         super().__init__(*args, **kwargs)
         self.assertIsNotNone(self.request_handler)
         self.server_address = ('127.0.0.1', random.randint(65000, 65535))
-        self.server_process = Process(target=TestingHTTPServer.run_server,
-                                      args=(self.server_address, self.request_handler))
+        self.server_process = ForkProcess(target=TestingHTTPServer.run_server,
+                                          args=(self.server_address, self.request_handler))
 
     def setUp(self):
         self.server_process.start()
@@ -583,8 +586,8 @@ class TestDefaultSchemaHeader(TestingHttpServerTestCase):
         self.client = self.clientWithKwargs(schema='my_custom_schema')
 
     def tearDown(self):
-        super().tearDown()
         self.client.close()
+        super().tearDown()
 
     def test_default_schema(self):
         self.client.sql('SELECT 1')
